@@ -54,7 +54,6 @@ import bzrlib.api
 from bzrlib import (
     branch,
     config,
-    errors,
     )
 from bzrlib.commands import plugin_cmds
 
@@ -75,17 +74,8 @@ if __name__ != 'bzrlib.plugins.gtk':
     from bzrlib.trace import warning
     warning("Not running as bzrlib.plugins.gtk, things may break.")
 
-def import_pygtk():
-    try:
-        import pygtk
-    except ImportError:
-        raise errors.BzrCommandError("PyGTK not installed.")
-    pygtk.require('2.0')
-    return pygtk
-
 
 def set_ui_factory():
-    import_pygtk()
     from ui import GtkUIFactory
     import bzrlib.ui
     bzrlib.ui.ui_factory = GtkUIFactory()
@@ -139,25 +129,17 @@ for cmd, aliases in commands.iteritems():
                               "bzrlib.plugins.gtk.commands")
 
 def save_commit_messages(*args):
-    from bzrlib.plugins.gtk import commit
-    commit.save_commit_messages(*args)
+    from bzrlib.plugins.gtk import commitmsgs
+    commitmsgs.save_commit_messages(*args)
 
 branch.Branch.hooks.install_named_hook('post_uncommit',
                                        save_commit_messages,
                                        "Saving commit messages for gcommit")
 
-credential_store_registry = getattr(config, "credential_store_registry", None)
-if credential_store_registry is not None:
-    try:
-        credential_store_registry.register_lazy(
-            "gnome-keyring", "bzrlib.plugins.gtk.keyring", "GnomeKeyringCredentialStore",
-            help="The GNOME Keyring.", fallback=True)
-    except TypeError:
-    # Fallback credentials stores were introduced in Bazaar 1.15
-        credential_store_registry.register_lazy(
-            "gnome-keyring", "bzrlib.plugins.gtk.keyring", "GnomeKeyringCredentialStore",
-            help="The GNOME Keyring.")
-
+option_registry = getattr(config, "option_registry", None)
+if option_registry is not None:
+    config.option_registry.register_lazy('nautilus_integration',
+            'bzrlib.plugins.gtk.config', 'opt_nautilus_integration')
 
 def load_tests(basic_tests, module, loader):
     testmod_names = [
@@ -168,8 +150,8 @@ def load_tests(basic_tests, module, loader):
     try:
         result = basic_tests
         try:
-            import_pygtk()
-        except errors.BzrCommandError:
+            import gi.repository.Gtk
+        except ImportError:
             return basic_tests
         basic_tests.addTest(loader.loadTestsFromModuleNames(
                 ["%s.%s" % (__name__, tmn) for tmn in testmod_names]))
@@ -179,7 +161,3 @@ def load_tests(basic_tests, module, loader):
             sys.setdefaultencoding(default_encoding)
     return basic_tests
 
-
-def _i18n(text):
-    # Stub until we support proper i18n
-    return text
