@@ -14,71 +14,68 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-try:
-    import pygtk
-    pygtk.require("2.0")
-except:
-    pass
-
 import subprocess
 
-import gtk
-import gobject
+from gi.repository import Gtk
+from gi.repository import GObject
 
 from bzrlib.config import GlobalConfig
-from bzrlib.plugins.gtk import _i18n
+from bzrlib.plugins.gtk.i18n import _i18n
+from bzrlib.plugins.gtk.dialog import (
+    error_dialog,
+    warning_dialog,
+    )
 
-from dialog import error_dialog, warning_dialog
-from errors import show_bzr_error
 
-class ConflictsDialog(gtk.Dialog):
+class ConflictsDialog(Gtk.Dialog):
     """ This dialog displays the list of conflicts. """
+
     def __init__(self, wt, parent=None):
         """ Initialize the Conflicts dialog. """
-        gtk.Dialog.__init__(self, title="Conflicts - Olive",
-                                  parent=parent,
-                                  flags=0,
-                                  buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_CANCEL))
-        
+        super(ConflictsDialog, self).__init__(
+            title="Conflicts - Olive", parent=parent, flags=0,
+            buttons=(Gtk.STOCK_CLOSE, Gtk.ResponseType.CANCEL))
+
         # Get arguments
         self.wt = wt
-        
+
         # Create the widgets
-        self._scrolledwindow = gtk.ScrolledWindow()
-        self._treeview = gtk.TreeView()
-        self._label_diff3 = gtk.Label(_i18n("External utility:"))
-        self._entry_diff3 = gtk.Entry()
-        self._image_diff3 = gtk.Image()
-        self._button_diff3 = gtk.Button()
-        self._hbox_diff3 = gtk.HBox()
-        
+        self._scrolledwindow = Gtk.ScrolledWindow()
+        self._treeview = Gtk.TreeView()
+        self._label_diff3 = Gtk.Label(label=_i18n("External utility:"))
+        self._entry_diff3 = Gtk.Entry()
+        self._image_diff3 = Gtk.Image()
+        self._button_diff3 = Gtk.Button()
+        self._hbox_diff3 = Gtk.HBox()
+
         # Set callbacks
         self._button_diff3.connect('clicked', self._on_diff3_clicked)
-        
+
         # Set properties
-        self._scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC,
-                                        gtk.POLICY_AUTOMATIC)
-        self._image_diff3.set_from_stock(gtk.STOCK_APPLY, gtk.ICON_SIZE_BUTTON)
+        self._scrolledwindow.set_policy(Gtk.PolicyType.AUTOMATIC,
+                                        Gtk.PolicyType.AUTOMATIC)
+        self._image_diff3.set_from_stock(Gtk.STOCK_APPLY, Gtk.IconSize.BUTTON)
         self._button_diff3.set_image(self._image_diff3)
         self._entry_diff3.set_text(self._get_diff3())
         self._hbox_diff3.set_spacing(3)
-        self.vbox.set_spacing(3)
+        content_area = self.get_content_area()
+        content_area.set_spacing(3)
         self.set_default_size(400, 300)
-        
+
         # Construct dialog
-        self._hbox_diff3.pack_start(self._label_diff3, False, False)
-        self._hbox_diff3.pack_start(self._entry_diff3, True, True)
-        self._hbox_diff3.pack_start(self._button_diff3, False, False)
+        self._hbox_diff3.pack_start(self._label_diff3, False, False, 0)
+        self._hbox_diff3.pack_start(self._entry_diff3, True, True, 0)
+        self._hbox_diff3.pack_start(self._button_diff3, False, False, 0)
         self._scrolledwindow.add(self._treeview)
-        self.vbox.pack_start(self._scrolledwindow, True, True)
-        self.vbox.pack_start(self._hbox_diff3, False, False)
-        
+        content_area.pack_start(self._scrolledwindow, True, True, 0)
+        content_area.pack_start(self._hbox_diff3, False, False, 0)
+
         # Create the conflict list
         self._create_conflicts()
-        
+
         # Show the dialog
-        self.vbox.show_all()
-    
+        content_area.show_all()
+
     def _get_diff3(self):
         """ Get the specified diff3 utility. Default is meld. """
         config = GlobalConfig()
@@ -86,31 +83,31 @@ class ConflictsDialog(gtk.Dialog):
         if diff3 is None:
             diff3 = 'meld'
         return diff3
-    
+
     def _set_diff3(self, cmd):
         """ Set the default diff3 utility to cmd. """
         config = GlobalConfig()
         config.set_user_option('gconflicts_diff3', cmd)
-    
+
     def _create_conflicts(self):
         """ Construct the list of conflicts. """
         if len(self.wt.conflicts()) == 0:
-            self.model = gtk.ListStore(gobject.TYPE_STRING)
+            self.model = Gtk.ListStore(GObject.TYPE_STRING)
             self._treeview.set_model(self.model)
-            self._treeview.append_column(gtk.TreeViewColumn(_i18n('Conflicts'),
-                                         gtk.CellRendererText(), text=0))
-            self._treeview.set_headers_visible(False)            
+            self._treeview.append_column(Gtk.TreeViewColumn(_i18n('Conflicts'),
+                                         Gtk.CellRendererText(), text=0))
+            self._treeview.set_headers_visible(False)
             self.model.append([ _i18n("No conflicts in working tree.") ])
             self._button_diff3.set_sensitive(False)
         else:
-            self.model = gtk.ListStore(gobject.TYPE_STRING,
-                                       gobject.TYPE_STRING,
-                                       gobject.TYPE_STRING)
+            self.model = Gtk.ListStore(GObject.TYPE_STRING,
+                                       GObject.TYPE_STRING,
+                                       GObject.TYPE_STRING)
             self._treeview.set_model(self.model)
-            self._treeview.append_column(gtk.TreeViewColumn(_i18n('Path'),
-                                         gtk.CellRendererText(), text=0))
-            self._treeview.append_column(gtk.TreeViewColumn(_i18n('Type'),
-                                         gtk.CellRendererText(), text=1))
+            self._treeview.append_column(Gtk.TreeViewColumn(_i18n('Path'),
+                                         Gtk.CellRendererText(), text=0))
+            self._treeview.append_column(Gtk.TreeViewColumn(_i18n('Type'),
+                                         Gtk.CellRendererText(), text=1))
             self._treeview.set_search_column(0)
             for conflict in self.wt.conflicts():
                 if conflict.typestring == 'path conflict':
@@ -133,29 +130,29 @@ class ConflictsDialog(gtk.Dialog):
                     t = _i18n("deleting parent")
                 else:
                     t = _i18n("unknown type of conflict")
-                
-                self.model.append([ conflict.path, t, conflict.typestring ]) 
-    
+
+                self.model.append([ conflict.path, t, conflict.typestring ])
+
     def _get_selected_file(self):
         """ Return the selected conflict's filename. """
         treeselection = self._treeview.get_selection()
         (model, iter) = treeselection.get_selected()
-        
+
         if iter is None:
             return None
         else:
             return model.get_value(iter, 0)
-    
+
     def _get_selected_type(self):
         """ Return the type of the selected conflict. """
         treeselection = self._treeview.get_selection()
         (model, iter) = treeselection.get_selected()
-        
+
         if iter is None:
             return None
         else:
             return model.get_value(iter, 2)
-    
+
     def _on_diff3_clicked(self, widget):
         """ Launch external utility to resolve conflicts. """
         self._set_diff3(self._entry_diff3.get_text())
