@@ -14,17 +14,18 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-from bzrlib import tests
 
 def load_tests(basic_tests, module, loader):
     testmod_names = [
         'test_annotate_config',
+        'test_avatarsbox',
         'test_commit',
         'test_diff',
         'test_history',
+        'test_graphcell',
         'test_linegraph',
-        'test_preferences',
         'test_revisionview',
+        'test_treemodel',
         ]
 
     basic_tests.addTest(loader.loadTestsFromModuleNames(
