@@ -16,6 +16,8 @@
 
 """Test the RevisionView functionality."""
 
+import os
+
 from bzrlib import (
     tests,
     )
@@ -27,12 +29,22 @@ except ImportError:
 from bzrlib.plugins.gtk import revisionview
 
 
+def fake_icon_path(*args):
+    return os.path.join(
+        os.path.dirname(__file__),  '..', 'icons', *args)
+
+
 class TestPendingRevisions(tests.TestCaseWithMemoryTransport):
 
+    def setUp(self):
+        super(TestPendingRevisions, self).setUp()
+        self.overrideAttr(revisionview, 'icon_path', new=fake_icon_path)
+
     def assertBufferText(self, text, buffer):
         """Check the text stored in the buffer."""
         self.assertEqual(text, buffer.get_text(buffer.get_start_iter(),
-                                               buffer.get_end_iter()))
+                                               buffer.get_end_iter(),
+                                               True))
 
     def test_create_view(self):
         builder = self.make_branch_builder('test')
@@ -41,6 +53,7 @@ class TestPendingRevisions(tests.TestCaseWithMemoryTransport):
         b = builder.get_branch()
 
         rv = revisionview.RevisionView(b)
+        self.addCleanup(rv.destroy)
         rev = b.repository.get_revision('A')
         rv.set_revision(rev)
         self.assertEqual(rev.committer, rv.committer.get_text())
@@ -61,6 +74,7 @@ class TestPendingRevisions(tests.TestCaseWithMemoryTransport):
         b = tree.branch
 
         rv = revisionview.RevisionView(b)
+        self.addCleanup(rv.destroy)
         rev = b.repository.get_revision('A')
         rv.set_revision(rev)
 
@@ -81,10 +95,11 @@ class TestPendingRevisions(tests.TestCaseWithMemoryTransport):
         b = tree.branch
 
         rv = revisionview.RevisionView(b)
+        self.addCleanup(rv.destroy)
         rev = b.repository.get_revision('A')
         rv.set_revision(rev)
 
         self.assertEqual(rev.committer, rv.committer.get_text())
         self.assertFalse(rv.file_info_box.get_property('visible'))
-        log = self._get_log(True)
+        log = self.get_log()
         self.assertContainsRe(log, 'Invalid per-file info for revision:A')
